import { History } from 'history';
import type { Location, Matched, Options, BaseRoute, RouterInstance, ResolveView } from './types';
/**
 * Create a router instance.
 * @group Methods
 * @category Router
 * @param routes routes config
 * @param history {@link https://www.npmjs.com/package/history history} instance
 * @param resolveView a callback to resolve view. see {@link defaultResolveView}
 * @param options options
 * @returns a router instance
 */
export declare function create<R extends BaseRoute = BaseRoute, V = any>(routes: R | R[], history: History, resolveView: ResolveView<R, V>, options?: Options<V>): RouterInstance<R, V>;
export declare function getHistoryState({ history }: Pick<RouterInstance<any>, 'history'>): {
    index: number;
    locationStack: Location<any>[];
};
export declare function getCurrentView<R extends BaseRoute = BaseRoute>(router: RouterInstance<R>): any;
/**
 * Match a path.
 * @group Methods
 * @category Router
 * @param router router instance
 * @param pathname the pathname
 * @returns the matched result
 */
export declare function match<R extends BaseRoute = BaseRoute>(router: RouterInstance<R>, pathname: string): Matched<R>[] | undefined;
/**
 * Path to Location.
 * @group Methods
 * @category Router
 * @param router router instance
 * @param to path string
 * @param state the state of location
 * @returns location
 */
export declare function toLocation<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>, to: string, state?: any): Location;
/**
 * Resolve a location.
 * @group Methods
 * @category Router
 * @param router router instance
 * @param location history instance
 * @returns resolve task(a promise)
 */
export declare function resolve<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>, location: Location): Promise<V>;
/**
 * Resolve a path.
 * @group Methods
 * @category Router
 * @param router router instance
 * @param to the path
 * @param state state of the path location
 * @returns resolve task(a promise)
 */
export declare function resolveTo<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>, to: string, state?: any): Promise<V>;
/**
 * Commit the resolve task and push history.
 * @group Methods
 * @category Router
 * @param router router instance
 * @param resolvePromise resolve task(a promise)
 * @param location the location to resolved
 */
export declare function commit<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>, resolvePromise: Promise<V>, location: Location): Promise<void>;
/**
 * Commit the resolve task and replace history.
 * @group Methods
 * @category Router
 * @param router router instance
 * @param resolvePromise resolve task(a promise)
 * @param location the location to resolved
 */
export declare function commitReplace<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>, resolvePromise: Promise<V>, location: Location): Promise<void>;
/**
 * Navigate to a new path.
 * @group Methods
 * @category Router
 * @param router router instance
 * @param to path string
 * @param state location state
 */
export declare function navigate<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>, to: string, state?: any): Promise<void>;
/**
 * Refresh the page.
 * @group Methods
 * @category Router
 * @param router router instance
 */
export declare function refresh<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>): Promise<void>;
/**
 * Navigate in history stack.
 * @group Methods
 * @category Router
 * @param router router instance
 * @param delta history stack index
 */
export declare function go<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>, delta: number): void;
/**
 * Forward in history stack.
 * @group Methods
 * @category Router
 * @param router router instance
 */
export declare function forward<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>): void;
/**
 * Back in history stack.
 * @group Methods
 * @category Router
 * @param router router instance
 */
export declare function back<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>): void;
/**
 * Create href of a route path. For {@link Link Link Component} hover url preview.
 * @group Methods
 * @category Router
 * @param router router instance
 * @param to route path
 * @returns href
 */
export declare function createHref<R extends BaseRoute = BaseRoute, V = any>({ baseUrl, history }: RouterInstance<R, V>, to: string): string;
/**
 * Cancel the current navigate.
 * @group Methods
 * @category Router
 * @param router router instance
 */
export declare function cancel<R extends BaseRoute = BaseRoute, V = any>({ cancelAll, onLoadingChange }: RouterInstance<R, V>): void;
export declare function initHistoryStack<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>): Promise<void>;
/**
 * Listen the history change.
 * @group Methods
 * @category Router
 * @param router router instance
 * @param onViewChange a callback function will be call when view changed
 * @returns unlisten - A function that may be used to stop listening
 */
export declare function listen<R extends BaseRoute = BaseRoute, V = any>(router: RouterInstance<R, V>, onViewChange: (v: V) => void): () => void;
